#
# spec file for package picom
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           picom
Version:        9.1
Release:        bp155.1.8
Summary:        Stand-alone compositor for X11
License:        MIT AND MPL-2.0
Group:          System/X11/Utilities
URL:            https://github.com/yshui/picom
Source0:        https://github.com/yshui/picom/archive/v%{version}.tar.gz
Source1:        picom.desktop
BuildRequires:  asciidoc
BuildRequires:  c_compiler
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  uthash-devel
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libconfig)
BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libxdg-basedir)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-damage)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-present)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-renderutil)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-sync)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xcb-xinerama)
BuildRequires:  pkgconfig(xext)
Requires:       hicolor-icon-theme
Obsoletes:      compton <= 0.1.0
Provides:       compton = %{version}

%description
Picom is a stand-alone compositor for X11. It supports both GLX and
XRender backends and has various options to control shadows, blur
and fade animations.

%prep
%setup -q

%build
%meson -Dwith_docs=true
%meson_build

%install
%meson_install
mv %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/compton.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
mv %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/compton.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
rm %{buildroot}%{_datadir}/applications/compton.desktop

cp %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%license LICENSES/MPL-2.0 LICENSES/MIT COPYING
%doc CONTRIBUTORS README.md README_orig.md picom.sample.conf
%{_bindir}/*
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-trans.1%{?ext_man}

%changelog
* Sat May 28 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 9.1:
  * Bug Fixes:
    [#770] #778
  * No further changelog
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 8.2:
  * Fixes assertion failures related to WIN_FLAGS_SHADOW_STALE, see #479
  * write-pid-path in configuration file now accepted, see #492
  * Pid files are now deleted during shutdown, see #492
  * Build fixes for certain platforms, see #501, #502
* Sun Jun 14 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Since it requires dbus, use dbus by default.
* Sat May  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Updated to version 8
  * You can now use the time variable in window shaders to get a
    timestamp. An example usage is to create animated effects,
    e.g. https://streamable.com/e0x7r
  * --max-brightness, which allows you to dim windows that are
    too bright. When enabled, all windows' average brightness will
    be clamped to the set value.
  * Automatic configuration file reloading after it's changed.
  * A lot of the artifacts seen with blur and use-damage enabled
    are fixed.
  * _NET_WM_BYPASS_COMPOSITOR property are now handled.
    (Related to i3/i3lock#204)
  * Completely transparent windows won't have a blurred background
    anymore.
  * Improved fullscreen window detection. Now EWMH is used to
    detect fullscreen windows as well. You can turn it off with
  - -no-ewmh-fullscreen
  * Various improvments to the inverter.sh script
  * wintype notify has been renamed to notification to match the
    EWMH names. (Old name still works)
  * picom no longer sets the opacity property on windows based on
    opacity rules. This is to fix the problem where picom "forgets"
    it set the opacity property after, e.g., window manager
    restarts.
  * libxdg-basedir is no longer a dependency
  * Fixed wrong client window detection after i3wm restarts
  * Fixed wallpaper disappearing after screen resolution changes.
  * Fixed crashing when a really big window is created with shadow
  * Fixed --frame-opacity with the experimental backends
  * --blur-* command line options are now handled properly
  * Various build fixes
  * Various memory leakage fixes
  * Various documentation fixes and improvments
  * Various other crash, assertion failure fixes
  * Fixed some left over problems related to terminals in floating
    scratchpads losing transparency after restarting i3
  * Using these options is now an error: alpha-step, -d, -S,
  - -no-named-pixmap xrender-sync. They were deprecated in v5.
    paint-on-overlay, --dbe. They were deprecated in v4.
  * Error messages will no longer be printed for these removed
    options: glx-use-copysubbuffermesa, glx-copy-from-front.
    They were removed in v7
* Mon Nov 18 2019 9+suse@cirno.systems
- init, 7.4+159.g9a88d97
